// -----------------------------------------------------------------------------
// Enemy Flag Server Plugin SDK for Delphi
// Copyright 2007 Bartomiej Baron
// http://www.bbproject.net
// -----------------------------------------------------------------------------
// Server plugin version: 2 (GameVerion >= 1.8.8)
// -----------------------------------------------------------------------------
// Zaleca sie usuniecie nieuzywanych zdarzen oraz procedur/funkcji w celu
// zwiekszenia wydajnosci wtyczki.
// -----------------------------------------------------------------------------
library efplugin;

// -----------------------------------------------------------------------------
uses
  SysUtils,
  Classes;

// -----------------------------------------------------------------------------
const
  PLUGIN_NAME = 'Enemy Flag Server Plugin';

// -----------------------------------------------------------------------------
const
  PING_NONE = 65535;
  PING_BOT = 65534;

// -----------------------------------------------------------------------------
type
  TClientData = record
    IP: PChar;          // adres IP
    Bot: Boolean;       // bot
    Ping: Integer;      // opoznienie
    Login: record
      Name: PChar;      // nazwa konta logowania w serwisie bbproject.net
      Status: Byte;     // stan logowania (0 - niezalogowany, 2 - zalogowany)
      end;
    Name: PChar;        // nazwa gracza
    Color: Byte;        // kolor panstwa gracza
    Spectator: Boolean; // tryb obserwatora
    Team: Byte;         // numer druzyny
    Time: Integer;      // czas przebywania gracza na serwerze podany w sekundach
    end;

// -----------------------------------------------------------------------------
type
  TExecLine = procedure(Command: PChar); stdcall;
  TSetString = procedure(ClNum: Integer; Text: PChar; Color: Byte); stdcall; // Color: 0-16
  TSetWindow = procedure(ClNum: Integer; Text: PChar); stdcall;
  TGetClientData = function(ClNum: Integer): TClientData; stdcall;
  TToggleClientSpectator = procedure(ClNum: Integer); stdcall;
  TChangeClientTeam = procedure(ClNum: Integer; Team: Byte); stdcall;

// -----------------------------------------------------------------------------
var
  ExecLine: TExecLine;
  SetString: TSetString;
  SetWindow: TSetWindow;
  GetClientData: TGetClientData;
  ToggleClientSpectator: TToggleClientSpectator;
  ChangeClientTeam: TChangeClientTeam;

// -----------------------------------------------------------------------------
// Zdarzenie wywolywane tuz po zaladowaniu rozszerzenia do pamieci serwera.
// Funkcja winna zwrocic wynik bedacy nazwa rozszerzenia.
// -----------------------------------------------------------------------------
// PluginVersion - wersja mechanizmu obslugi rozszerzen serwera.
// GameVersion - wersja serwera gry.
// -----------------------------------------------------------------------------
function OnLoad(PluginVersion: Byte; GameVersion: PChar): PChar; stdcall;
begin

Result := PLUGIN_NAME;

end;

// -----------------------------------------------------------------------------
// Zdarzenie wywolywane tuz po zaladowaniu rozszerzenia do pamieci serwera.
// -----------------------------------------------------------------------------
// PExecLine - wskaznik do procedury pozwalajacej na wykonanie polecenia
//   konsoli.
// PSetString - wskaznik do procedury wyswietlajacej dowolny tekst w oknie
//   wiadomosci gry.
// PSetWindow - wskaznik do procedury wyswietlajacy okno powiadomienia gry.
// PGetClientData - wskaznik do funkcji pobierajacej szczegolowe dane nt. danego
//   klienta.
// PToggleClientSpectator - wskaznik do procedury przelaczajacej tryb
//   obserwatora danego klienta.
// PChangeClientTeam - wskaznik do procedury zmieniajacej druzyne danego
//   klienta.
// -----------------------------------------------------------------------------
procedure OnLoadEx(PExecLine, PSetString, PSetWindow, PGetClientData,
  PToggleClientSpectator, PChangeClientTeam: Pointer); stdcall;
begin

ExecLine := PExecLine;
SetString := PSetString;
SetWindow := PSetWindow;
GetClientData := PGetClientData;
ToggleClientSpectator := PToggleClientSpectator;
ChangeClientTeam := PChangeClientTeam;

end;

// -----------------------------------------------------------------------------
// Zdarzenie wywolywane tuz przed zwolnieniem rozszerzenie z pamieci.
// -----------------------------------------------------------------------------
procedure OnUnload; stdcall;
begin

end;

// -----------------------------------------------------------------------------
// Zdarzenie wywolywane w kazdym cyklu przetwarzania serwera (raz na sekunde).
// -----------------------------------------------------------------------------
procedure OnProcess; stdcall;
begin

end;

// -----------------------------------------------------------------------------
// Zdarzenie na okolicznosc podlaczenia nowego gracza do serwera.
// -----------------------------------------------------------------------------
// ClNum - unikalny numer identyfikacyjny danego klienta.
// -----------------------------------------------------------------------------
procedure OnClientConnect(ClNum: Integer); stdcall;
begin

end;

// -----------------------------------------------------------------------------
// Zdarzenie odlaczenia klienta od serwera.
// -----------------------------------------------------------------------------
// ClNum - unikalny numer identyfikacyjny danego klienta.
// -----------------------------------------------------------------------------
procedure OnClientDisconnect(ClNum: Integer); stdcall;
begin

end;

// -----------------------------------------------------------------------------
// Zdarzenie wywolywane w momencie wydania przez klientanierozpoznawalnej przez
// serer komendy. Funkcja winna w wyniku zwrocic tekst wyswietlany w oknie
// wiadomosci gry.
// -----------------------------------------------------------------------------
// ClNum - unikalny numer identyfikacyjny danego klienta.
// CustomCommand - tresc komendy wydanej przez klienta.
// -----------------------------------------------------------------------------
function OnClientCustomCommand(ClNum: Integer; CustomCommand: PChar): PChar; stdcall;
begin

Result := '';

end;

// -----------------------------------------------------------------------------
// Zdarzenie zmiany trybu obserwatora przez klienta. Funkcja jako wynik powinna
// zwrocic wartosc mowiaca o fakcie zezwolenia na operacje lub jej odmowy.
// -----------------------------------------------------------------------------
// ClNum - unikalny numer identyfikacyjny danego klienta.
// SrcSpectator - stan okreslajacy tryb obserwatora przed wykonaniem zmiany.
// DestSpectator - stan okreslajacy tryb obserwatora po zmianie.
// -----------------------------------------------------------------------------
function OnClientToggleSpectator(ClNum: Integer;
  SrcSpectator, DestSpectator: Boolean): Boolean; stdcall;
begin

Result := True;

end;

// -----------------------------------------------------------------------------
// Zdarzenie zmiany druzyny przez klienta. Funkcja jako wynik powinna zwrocic
// wartosc mowiaca o fakcie zezwolenia na operacje lub jej odmowy.
// -----------------------------------------------------------------------------
// ClNum - unikalny numer identyfikacyjny danego klienta.
// SrcTeam - numer druzyny przed wykonaniem zmiany.
// DestTeam - numer druzyny po zmianie.
// -----------------------------------------------------------------------------
function OnClientChangeTeam(ClNum: Integer; SrcTeam, DestTeam: Byte): Boolean; stdcall;
begin

Result := True;

end;

// -----------------------------------------------------------------------------
// Zdarzenie wywolywane w momencie weryfikacji graczy przed rozpoczeciem gry.
// Zwrocona wartosc funkcji zezwala lub odmawia danemu klientowi uczestnictwa
// w aktualnie rozpoczynanej grze.
// -----------------------------------------------------------------------------
// ClNum - unikalny numer identyfikacyjny danego klienta.
// -----------------------------------------------------------------------------
function OnClientCanPlay(ClNum: Integer): Boolean; stdcall;
begin

Result := True;

end;

// -----------------------------------------------------------------------------
// Zdarzenie przywolywane w momencie rozpoczecia nowej gry.
// -----------------------------------------------------------------------------
// ClCount - ilosc graczy bioracych udzial w aktualnej rozgrywce.
// ClNumArray - tablica numerow identyfikacyjnych graczy bioracych udzial w
//   rozgrywce.
// Map - nazwa rozgrywanej mapy.
// -----------------------------------------------------------------------------
procedure OnGameStart(ClCount: Byte; ClNumArray: array of Integer; Map: PChar); stdcall;
begin

end;

// -----------------------------------------------------------------------------
// Zdarzenie zakonczenia gry.
// -----------------------------------------------------------------------------
procedure OnGameEnd; stdcall;
begin

end;

// -----------------------------------------------------------------------------
// Zdarzenie wywolywane w momencie zabicia jednego z graczy.
// -----------------------------------------------------------------------------
// DestroyClNum - numer identyfikacyjny zabitego gracza.
// EnemyClNum - numer identyfikacyjny oprawcy.
// -----------------------------------------------------------------------------
procedure OnPlayerDestroy(DestroyClNum, EnemyClNum: Integer); stdcall;
begin

end;

// -----------------------------------------------------------------------------
// Zdarzenie wywolywane w momencie zakonczenia tury gracza.
// -----------------------------------------------------------------------------
// ClNum - numer identyfikacyjny danego gracza.
// TurnNum - aktualny numer tury (0 - pierwsza tura).
// -----------------------------------------------------------------------------
procedure OnEndTurn(ClNum, TurnNum: Integer); stdcall;
begin

end;

// -----------------------------------------------------------------------------
exports
  OnLoad,
  OnLoadEx,
  OnUnload,
  OnProcess,
  OnClientConnect,
  OnClientDisconnect,
  OnClientCustomCommand,
  OnClientToggleSpectator,
  OnClientChangeTeam,
  OnClientCanPlay,
  OnGameStart,
  OnGameEnd,
  OnPlayerDestroy,
  OnEndTurn;

begin
end.